bridge.change


available-evidence-kindsclj

(available-evidence-kinds profile subsystems)
source

categorize-change-kindsclj

(categorize-change-kinds profile changed-files)
source

change-assessmentclj

(change-assessment profile policy changed-files change-id)
source

change-sourcesclj

(change-sources change-kinds)
source

existing-evidence-classesclj

(existing-evidence-classes profile subsystems)

Return executable evidence classes configured for the affected subsystems.

Artifact or documentation presence never counts as executable evidence.

Return executable evidence classes configured for the affected subsystems.

Artifact or documentation presence never counts as executable evidence.
sourceraw docstring

infer-categoriesclj

(infer-categories change-kinds)
source

matched-change-filesclj

(matched-change-files profile changed-files subsystems matched-rules)
source

normalize-evidence-kindclj

(normalize-evidence-kind kind)
source

risk-classclj

(risk-class subsystems)
source

cljdoc builds & hosts documentation for Clojure/Script libraries