bridge.cli


*exit-fn*clj

source

-mainclj

(-main & args)
source

append-gitignore-entry!clj

(append-gitignore-entry! path entry)
source

change-selectionclj

(change-selection opts)
source

command-autoclj

(command-auto opts)
source

command-checkclj

(command-check opts)
source

command-debug-profileclj

(command-debug-profile opts)
source

command-initclj

(command-init opts)
source

command-install-hooksclj

(command-install-hooks opts)
source

command-list-evidenceclj

(command-list-evidence opts)
source

command-migrate-profileclj

(command-migrate-profile opts)
source

command-nextclj

(command-next opts)
source

command-run-evidenceclj

(command-run-evidence opts)
source

command-validate-artifactclj

(command-validate-artifact opts pos)
source

command-validate-dirclj

(command-validate-dir opts pos)
source

default-policyclj

(default-policy project-name)
source

default-profile-pathsclj

source

discover-legacy-profile-pathclj

(discover-legacy-profile-path)
(discover-legacy-profile-path root)
source

discover-profile-pathclj

(discover-profile-path)
(discover-profile-path root)

Return the first profile candidate that exists under root (default: cwd), as a root-relative path.

Return the first profile candidate that exists under root (default: cwd),
as a root-relative path.
sourceraw docstring

dispatchclj

(dispatch args)
source

ensure-vectorclj

(ensure-vector x)
source

help-textclj

source

hook-blockclj

(hook-block profile-path)
source

hook-marker-endclj

source

hook-marker-startclj

source

infer-canonical-commandsclj

(infer-canonical-commands project-root)
source

legacy-hook-marker-endclj

source

legacy-hook-marker-startclj

source

legacy-profile-pathsclj

source

load-profile+policyclj

(load-profile+policy opts)
source

migrate-profile-commandclj

(migrate-profile-command legacy-path)
source

parse-argsclj

(parse-args args)
source

parse-valueclj

(parse-value s)
source

pre-commit-hook-blockclj

(pre-commit-hook-block profile-path)
source

println-dataclj

(println-data data)
source

profile-optionclj

(profile-option opts)
source

require-optionclj

(require-option opts k)
source

starter-profile-dataclj

(starter-profile-data project-name root-path canonical-commands)
source

cljdoc builds & hosts documentation for Clojure/Script libraries