(discover-legacy-profile-path)(discover-legacy-profile-path root)(discover-profile-path)(discover-profile-path root)Return the first profile candidate that exists under root (default: cwd), as a root-relative path.
Return the first profile candidate that exists under root (default: cwd), as a root-relative path.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |